@@ -11,7 +11,6 @@ pub(crate) const CHOOSE_HELP: &str = "Select one or more recipes to run using a
 
 pub(crate) const DEFAULT_SHELL: &str = "sh";
 pub(crate) const DEFAULT_SHELL_ARG: &str = "-cu";
-pub(crate) const INIT_JUSTFILE: &str = "default:\n\techo 'Hello, world!'\n";
 
 #[derive(Debug, PartialEq)]
 pub(crate) struct Config {
@@ -34,7 +33,9 @@ pub(crate) struct Config {
 }
 
 mod cmd {
+  pub(crate) const CHANGELOG: &str = "CHANGELOG";
   pub(crate) const CHOOSE: &str = "CHOOSE";
+  pub(crate) const COMMAND: &str = "COMMAND";
   pub(crate) const COMPLETIONS: &str = "COMPLETIONS";
   pub(crate) const DUMP: &str = "DUMP";
   pub(crate) const EDIT: &str = "EDIT";
@@ -45,9 +46,9 @@ mod cmd {
   pub(crate) const SHOW: &str = "SHOW";
   pub(crate) const SUMMARY: &str = "SUMMARY";
   pub(crate) const VARIABLES: &str = "VARIABLES";
-  pub(crate) const COMMAND: &str = "COMMAND";
 
   pub(crate) const ALL: &[&str] = &[
+    CHANGELOG,
     CHOOSE,
     COMMAND,
     COMPLETIONS,
@@ -63,6 +64,7 @@ mod cmd {
   ];
 
   pub(crate) const ARGLESS: &[&str] = &[
+    CHANGELOG,
     COMPLETIONS,
     DUMP,
     EDIT,
@@ -240,6 +242,11 @@ impl Config {
           .help("Use <WORKING-DIRECTORY> as working directory. --justfile must also be set")
           .requires(arg::JUSTFILE),
       )
+      .arg(
+        Arg::with_name(cmd::CHANGELOG)
+          .long("changelog")
+          .help("Print changelog"),
+      )
       .arg(Arg::with_name(cmd::CHOOSE).long("choose").help(CHOOSE_HELP))
       .arg(
         Arg::with_name(cmd::COMMAND)
@@ -432,7 +439,9 @@ impl Config {
       }
     }
 
-    let subcommand = if matches.is_present(cmd::CHOOSE) {
+    let subcommand = if matches.is_present(cmd::CHANGELOG) {
+      Subcommand::Changelog
+    } else if matches.is_present(cmd::CHOOSE) {
       Subcommand::Choose {
         chooser: matches.value_of(arg::CHOOSER).map(str::to_owned),
         overrides,
@@ -532,409 +541,18 @@ impl Config {
     })
   }
 
-  pub(crate) fn run_subcommand(self) -> Result<(), i32> {
-    use Subcommand::*;
-
-    if self.subcommand == Init {
-      return self.init();
-    }
-
-    if let Completions { shell } = self.subcommand {
-      return Subcommand::completions(self.verbosity, &shell);
-    }
-
-    let search =
-      Search::find(&self.search_config, &self.invocation_directory).eprint(self.color)?;
-
-    if self.subcommand == Edit {
-      return self.edit(&search);
-    }
-
-    let src = fs::read_to_string(&search.justfile)
-      .map_err(|io_error| LoadError {
-        io_error,
-        path: &search.justfile,
+  pub(crate) fn require_unstable(&self, message: &str) -> Result<(), Error<'static>> {
+    if self.unstable {
+      Ok(())
+    } else {
+      Err(Error::Unstable {
+        message: message.to_owned(),
       })
-      .eprint(self.color)?;
-
-    let tokens = Lexer::lex(&src).eprint(self.color)?;
-    let ast = Parser::parse(&tokens).eprint(self.color)?;
-    let justfile = Analyzer::analyze(ast.clone()).eprint(self.color)?;
-
-    if self.verbosity.loud() {
-      for warning in &justfile.warnings {
-        if self.color.stderr().active() {
-          eprintln!("{:#}", warning);
-        } else {
-          eprintln!("{}", warning);
-        }
-      }
-    }
-
-    match &self.subcommand {
-      Choose { overrides, chooser } =>
-        self.choose(justfile, &search, overrides, chooser.as_deref())?,
-      Command { overrides, .. } => self.run(justfile, &search, overrides, &[])?,
-      Dump => Self::dump(ast)?,
-      Evaluate { overrides, .. } => self.run(justfile, &search, overrides, &[])?,
-      Format => self.format(ast, &search)?,
-      List => self.list(justfile),
-      Run {
-        arguments,
-        overrides,
-      } => self.run(justfile, &search, overrides, arguments)?,
-      Show { ref name } => self.show(&name, justfile)?,
-      Summary => self.summary(justfile),
-      Variables => Self::variables(justfile),
-      Completions { .. } | Edit | Init => unreachable!(),
-    }
-
-    Ok(())
-  }
-
-  fn choose(
-    &self,
-    justfile: Justfile,
-    search: &Search,
-    overrides: &BTreeMap<String, String>,
-    chooser: Option<&str>,
-  ) -> Result<(), i32> {
-    let recipes = justfile
-      .public_recipes(self.unsorted)
-      .iter()
-      .filter(|recipe| recipe.min_arguments() == 0)
-      .cloned()
-      .collect::<Vec<&Recipe<Dependency>>>();
-
-    if recipes.is_empty() {
-      if self.verbosity.loud() {
-        eprintln!("Justfile contains no choosable recipes.");
-      }
-      return Err(EXIT_FAILURE);
-    }
-
-    let chooser = chooser
-      .map(OsString::from)
-      .or_else(|| env::var_os(CHOOSER_ENVIRONMENT_KEY))
-      .unwrap_or_else(|| OsString::from(CHOOSER_DEFAULT));
-
-    let result = justfile
-      .settings
-      .shell_command(self)
-      .arg(&chooser)
-      .current_dir(&search.working_directory)
-      .stdin(Stdio::piped())
-      .stdout(Stdio::piped())
-      .spawn();
-
-    let mut child = match result {
-      Ok(child) => child,
-      Err(error) => {
-        if self.verbosity.loud() {
-          eprintln!(
-            "Chooser `{} {} {}` invocation failed: {}",
-            justfile.settings.shell_binary(self),
-            justfile.settings.shell_arguments(self).join(" "),
-            chooser.to_string_lossy(),
-            error
-          );
-        }
-        return Err(EXIT_FAILURE);
-      },
-    };
-
-    for recipe in recipes {
-      if let Err(error) = child
-        .stdin
-        .as_mut()
-        .expect("Child was created with piped stdio")
-        .write_all(format!("{}\n", recipe.name).as_bytes())
-      {
-        if self.verbosity.loud() {
-          eprintln!(
-            "Failed to write to chooser `{}`: {}",
-            chooser.to_string_lossy(),
-            error
-          );
-        }
-        return Err(EXIT_FAILURE);
-      }
-    }
-
-    let output = match child.wait_with_output() {
-      Ok(output) => output,
-      Err(error) => {
-        if self.verbosity.loud() {
-          eprintln!(
-            "Failed to read output from chooser `{}`: {}",
-            chooser.to_string_lossy(),
-            error
-          );
-        }
-        return Err(EXIT_FAILURE);
-      },
-    };
-
-    if !output.status.success() {
-      if self.verbosity.loud() {
-        eprintln!(
-          "Chooser `{}` returned error: {}",
-          chooser.to_string_lossy(),
-          output.status
-        );
-      }
-      return Err(output.status.code().unwrap_or(EXIT_FAILURE));
-    }
-
-    let stdout = String::from_utf8_lossy(&output.stdout);
-
-    let recipes = stdout
-      .trim()
-      .split_whitespace()
-      .map(str::to_owned)
-      .collect::<Vec<String>>();
-
-    self.run(justfile, search, overrides, &recipes)
-  }
-
-  fn dump(ast: Module) -> Result<(), i32> {
-    print!("{}", ast);
-    Ok(())
-  }
-
-  pub(crate) fn edit(&self, search: &Search) -> Result<(), i32> {
-    let editor = env::var_os("VISUAL")
-      .or_else(|| env::var_os("EDITOR"))
-      .unwrap_or_else(|| "vim".into());
-
-    let error = Command::new(&editor)
-      .current_dir(&search.working_directory)
-      .arg(&search.justfile)
-      .status();
-
-    match error {
-      Ok(status) =>
-        if status.success() {
-          Ok(())
-        } else {
-          if self.verbosity.loud() {
-            eprintln!("Editor `{}` failed: {}", editor.to_string_lossy(), status);
-          }
-          Err(status.code().unwrap_or(EXIT_FAILURE))
-        },
-      Err(error) => {
-        if self.verbosity.loud() {
-          eprintln!(
-            "Editor `{}` invocation failed: {}",
-            editor.to_string_lossy(),
-            error
-          );
-        }
-        Err(EXIT_FAILURE)
-      },
     }
   }
 
-  fn format(&self, ast: Module, search: &Search) -> Result<(), i32> {
-    if !self.unstable {
-      eprintln!(
-        "The `--fmt` command is currently unstable. Pass the `--unstable` flag to enable it."
-      );
-      return Err(EXIT_FAILURE);
-    }
-
-    if let Err(error) = File::create(&search.justfile).and_then(|mut file| write!(file, "{}", ast))
-    {
-      if self.verbosity.loud() {
-        eprintln!(
-          "Failed to write justfile to `{}`: {}",
-          search.justfile.display(),
-          error
-        );
-      }
-      Err(EXIT_FAILURE)
-    } else {
-      if self.verbosity.loud() {
-        eprintln!("Wrote justfile to `{}`", search.justfile.display());
-      }
-      Ok(())
-    }
-  }
-
-  pub(crate) fn init(&self) -> Result<(), i32> {
-    let search =
-      Search::init(&self.search_config, &self.invocation_directory).eprint(self.color)?;
-
-    if search.justfile.exists() {
-      if self.verbosity.loud() {
-        eprintln!("Justfile `{}` already exists", search.justfile.display());
-      }
-      Err(EXIT_FAILURE)
-    } else if let Err(err) = fs::write(&search.justfile, INIT_JUSTFILE) {
-      if self.verbosity.loud() {
-        eprintln!(
-          "Failed to write justfile to `{}`: {}",
-          search.justfile.display(),
-          err
-        );
-      }
-      Err(EXIT_FAILURE)
-    } else {
-      if self.verbosity.loud() {
-        eprintln!("Wrote justfile to `{}`", search.justfile.display());
-      }
-      Ok(())
-    }
-  }
-
-  fn list(&self, justfile: Justfile) {
-    // Construct a target to alias map.
-    let mut recipe_aliases: BTreeMap<&str, Vec<&str>> = BTreeMap::new();
-    for alias in justfile.aliases.values() {
-      if alias.is_private() {
-        continue;
-      }
-
-      if !recipe_aliases.contains_key(alias.target.name.lexeme()) {
-        recipe_aliases.insert(alias.target.name.lexeme(), vec![alias.name.lexeme()]);
-      } else {
-        let aliases = recipe_aliases.get_mut(alias.target.name.lexeme()).unwrap();
-        aliases.push(alias.name.lexeme());
-      }
-    }
-
-    let mut line_widths: BTreeMap<&str, usize> = BTreeMap::new();
-
-    for (name, recipe) in &justfile.recipes {
-      if recipe.private {
-        continue;
-      }
-
-      for name in iter::once(name).chain(recipe_aliases.get(name).unwrap_or(&Vec::new())) {
-        let mut line_width = UnicodeWidthStr::width(*name);
-
-        for parameter in &recipe.parameters {
-          line_width += UnicodeWidthStr::width(format!(" {}", parameter).as_str());
-        }
-
-        if line_width <= 30 {
-          line_widths.insert(name, line_width);
-        }
-      }
-    }
-
-    let max_line_width = cmp::min(line_widths.values().cloned().max().unwrap_or(0), 30);
-
-    let doc_color = self.color.stdout().doc();
-    print!("{}", self.list_heading);
-
-    for recipe in justfile.public_recipes(self.unsorted) {
-      let name = recipe.name();
-
-      for (i, name) in iter::once(&name)
-        .chain(recipe_aliases.get(name).unwrap_or(&Vec::new()))
-        .enumerate()
-      {
-        print!("{}{}", self.list_prefix, name);
-        for parameter in &recipe.parameters {
-          if self.color.stdout().active() {
-            print!(" {:#}", parameter);
-          } else {
-            print!(" {}", parameter);
-          }
-        }
-
-        // Declaring this outside of the nested loops will probably be more efficient,
-        // but it creates all sorts of lifetime issues with variables inside the loops.
-        // If this is inlined like the docs say, it shouldn't make any difference.
-        let print_doc = |doc| {
-          print!(
-            " {:padding$}{} {}",
-            "",
-            doc_color.paint("#"),
-            doc_color.paint(doc),
-            padding = max_line_width
-              .saturating_sub(line_widths.get(name).cloned().unwrap_or(max_line_width))
-          );
-        };
-
-        match (i, recipe.doc) {
-          (0, Some(doc)) => print_doc(doc),
-          (0, None) => (),
-          _ => {
-            let alias_doc = format!("alias for `{}`", recipe.name);
-            print_doc(&alias_doc);
-          },
-        }
-        println!();
-      }
-    }
-  }
-
-  fn run(
-    &self,
-    justfile: Justfile,
-    search: &Search,
-    overrides: &BTreeMap<String, String>,
-    arguments: &[String],
-  ) -> Result<(), i32> {
-    if let Err(error) = InterruptHandler::install(self.verbosity) {
-      warn!("Failed to set CTRL-C handler: {}", error);
-    }
-
-    let result = justfile.run(&self, search, overrides, arguments);
-
-    if !self.verbosity.quiet() {
-      result.eprint(self.color)
-    } else {
-      result.map_err(|err| err.code())
-    }
-  }
-
-  fn show(&self, name: &str, justfile: Justfile) -> Result<(), i32> {
-    if let Some(alias) = justfile.get_alias(name) {
-      let recipe = justfile.get_recipe(alias.target.name.lexeme()).unwrap();
-      println!("{}", alias);
-      println!("{}", recipe);
-      Ok(())
-    } else if let Some(recipe) = justfile.get_recipe(name) {
-      println!("{}", recipe);
-      Ok(())
-    } else {
-      if self.verbosity.loud() {
-        eprintln!("Justfile does not contain recipe `{}`.", name);
-        if let Some(suggestion) = justfile.suggest_recipe(name) {
-          eprintln!("{}", suggestion);
-        }
-      }
-      Err(EXIT_FAILURE)
-    }
-  }
-
-  fn summary(&self, justfile: Justfile) {
-    if justfile.count() == 0 {
-      if self.verbosity.loud() {
-        eprintln!("Justfile contains no recipes.");
-      }
-    } else {
-      let summary = justfile
-        .public_recipes(self.unsorted)
-        .iter()
-        .map(|recipe| recipe.name())
-        .collect::<Vec<&str>>()
-        .join(" ");
-      println!("{}", summary);
-    }
-  }
-
-  fn variables(justfile: Justfile) {
-    for (i, (_, assignment)) in justfile.assignments.iter().enumerate() {
-      if i > 0 {
-        print!(" ");
-      }
-      print!("{}", assignment.name);
-    }
-    println!();
+  pub(crate) fn run<'src>(self, loader: &'src Loader) -> Result<(), Error<'src>> {
+    self.subcommand.run(&self, loader)
   }
 }
 
@@ -948,7 +566,7 @@ mod tests {
   // have proper tests for all the flags, but this will do for now.
   #[test]
   fn help() {
-    const EXPECTED_HELP: &str = "just 0.9.9
+    const EXPECTED_HELP: &str = "just 0.10.0
 Casey Rodarmor <casey@rodarmor.com>
 🤖 Just a command runner \
                                  - https://github.com/casey/just
@@ -957,6 +575,7 @@ USAGE:
     just [FLAGS] [OPTIONS] [--] [ARGUMENTS]...
 
 FLAGS:
+        --changelog           Print changelog
         --choose              Select one or more recipes to run using a binary. If `--chooser` is \
                                  not passed the chooser
                               defaults to the value of $JUST_CHOOSER, falling back to `fzf`
@@ -1355,6 +974,11 @@ ARGS:
     },
   }
 
+  error! {
+    name: subcommand_conflict_changelog,
+    args: ["--list", "--changelog"],
+  }
+
   error! {
     name: subcommand_conflict_summary,
     args: ["--list", "--summary"],
@@ -1686,6 +1310,16 @@ ARGS:
     },
   }
 
+  error! {
+    name: changelog_arguments,
+    args: ["--changelog", "bar"],
+    error: ConfigError::SubcommandArguments { subcommand, arguments },
+    check: {
+      assert_eq!(subcommand, cmd::CHANGELOG);
+      assert_eq!(arguments, &["bar"]);
+    },
+  }
+
   error! {
     name: list_arguments,
     args: ["--list", "bar"],
@@ -1776,9 +1410,4 @@ ARGS:
       assert_eq!(overrides, map!{"bar": "baz"});
     },
   }
-
-  #[test]
-  fn init_justfile() {
-    testing::compile(INIT_JUSTFILE);
-  }
 }
