@@ -1,6 +1,6 @@
 use crate::common::*;
 
-use CompilationErrorKind::*;
+use CompileErrorKind::*;
 use TokenKind::*;
 
 /// Just language lexer
@@ -38,7 +38,7 @@ pub(crate) struct Lexer<'src> {
 
 impl<'src> Lexer<'src> {
   /// Lex `text`
-  pub(crate) fn lex(src: &str) -> CompilationResult<Vec<Token>> {
+  pub(crate) fn lex(src: &'src str) -> CompileResult<Vec<Token<'src>>> {
     Lexer::new(src).tokenize()
   }
 
@@ -70,7 +70,7 @@ impl<'src> Lexer<'src> {
 
   /// Advance over the character in `self.next`, updating `self.token_end`
   /// accordingly.
-  fn advance(&mut self) -> CompilationResult<'src, ()> {
+  fn advance(&mut self) -> CompileResult<'src, ()> {
     match self.next {
       Some(c) => {
         let len_utf8 = c.len_utf8();
@@ -92,7 +92,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Advance over N characters.
-  fn skip(&mut self, n: usize) -> CompilationResult<'src, ()> {
+  fn skip(&mut self, n: usize) -> CompileResult<'src, ()> {
     for _ in 0..n {
       self.advance()?;
     }
@@ -110,7 +110,7 @@ impl<'src> Lexer<'src> {
     self.token_end.offset - self.token_start.offset
   }
 
-  fn accepted(&mut self, c: char) -> CompilationResult<'src, bool> {
+  fn accepted(&mut self, c: char) -> CompileResult<'src, bool> {
     if self.next_is(c) {
       self.advance()?;
       Ok(true)
@@ -119,7 +119,7 @@ impl<'src> Lexer<'src> {
     }
   }
 
-  fn presume(&mut self, c: char) -> CompilationResult<'src, ()> {
+  fn presume(&mut self, c: char) -> CompileResult<'src, ()> {
     if !self.next_is(c) {
       return Err(self.internal_error(format!("Lexer presumed character `{}`", c)));
     }
@@ -129,7 +129,7 @@ impl<'src> Lexer<'src> {
     Ok(())
   }
 
-  fn presume_str(&mut self, s: &str) -> CompilationResult<'src, ()> {
+  fn presume_str(&mut self, s: &str) -> CompileResult<'src, ()> {
     for c in s.chars() {
       self.presume(c)?;
     }
@@ -199,7 +199,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Create an internal error with `message`
-  fn internal_error(&self, message: impl Into<String>) -> CompilationError<'src> {
+  fn internal_error(&self, message: impl Into<String>) -> CompileError<'src> {
     // Use `self.token_end` as the location of the error
     let token = Token {
       src:    self.src,
@@ -209,8 +209,8 @@ impl<'src> Lexer<'src> {
       length: 0,
       kind:   Unspecified,
     };
-    CompilationError {
-      kind: CompilationErrorKind::Internal {
+    CompileError {
+      kind: CompileErrorKind::Internal {
         message: message.into(),
       },
       token,
@@ -218,7 +218,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Create a compilation error with `kind`
-  fn error(&self, kind: CompilationErrorKind<'src>) -> CompilationError<'src> {
+  fn error(&self, kind: CompileErrorKind<'src>) -> CompileError<'src> {
     // Use the in-progress token span as the location of the error.
 
     // The width of the error site to highlight depends on the kind of error:
@@ -244,11 +244,11 @@ impl<'src> Lexer<'src> {
       length,
     };
 
-    CompilationError { token, kind }
+    CompileError { token, kind }
   }
 
-  fn unterminated_interpolation_error(interpolation_start: Token<'src>) -> CompilationError<'src> {
-    CompilationError {
+  fn unterminated_interpolation_error(interpolation_start: Token<'src>) -> CompileError<'src> {
+    CompileError {
       token: interpolation_start,
       kind:  UnterminatedInterpolation,
     }
@@ -289,7 +289,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Consume the text and produce a series of tokens
-  fn tokenize(mut self) -> CompilationResult<'src, Vec<Token<'src>>> {
+  fn tokenize(mut self) -> CompileResult<'src, Vec<Token<'src>>> {
     loop {
       if self.token_start.column == 0 {
         self.lex_line_start()?;
@@ -327,7 +327,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Handle blank lines and indentation
-  fn lex_line_start(&mut self) -> CompilationResult<'src, ()> {
+  fn lex_line_start(&mut self) -> CompileResult<'src, ()> {
     enum Indentation<'src> {
       // Line only contains whitespace
       Blank,
@@ -477,7 +477,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex token beginning with `start` outside of a recipe body
-  fn lex_normal(&mut self, start: char) -> CompilationResult<'src, ()> {
+  fn lex_normal(&mut self, start: char) -> CompileResult<'src, ()> {
     match start {
       '&' => self.lex_digraph('&', '&', AmpersandAmpersand),
       '!' => self.lex_digraph('!', '=', BangEquals),
@@ -513,7 +513,7 @@ impl<'src> Lexer<'src> {
     &mut self,
     interpolation_start: Token<'src>,
     start: char,
-  ) -> CompilationResult<'src, ()> {
+  ) -> CompileResult<'src, ()> {
     if self.rest_starts_with("}}") {
       // end current interpolation
       if self.interpolation_stack.pop().is_none() {
@@ -536,7 +536,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex token while in recipe body
-  fn lex_body(&mut self) -> CompilationResult<'src, ()> {
+  fn lex_body(&mut self) -> CompileResult<'src, ()> {
     enum Terminator {
       Newline,
       NewlineCarriageReturn,
@@ -599,14 +599,14 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex a single-character token
-  fn lex_single(&mut self, kind: TokenKind) -> CompilationResult<'src, ()> {
+  fn lex_single(&mut self, kind: TokenKind) -> CompileResult<'src, ()> {
     self.advance()?;
     self.token(kind);
     Ok(())
   }
 
   /// Lex a double-character token
-  fn lex_double(&mut self, kind: TokenKind) -> CompilationResult<'src, ()> {
+  fn lex_double(&mut self, kind: TokenKind) -> CompileResult<'src, ()> {
     self.advance()?;
     self.advance()?;
     self.token(kind);
@@ -621,7 +621,7 @@ impl<'src> Lexer<'src> {
     second: char,
     then: TokenKind,
     otherwise: TokenKind,
-  ) -> CompilationResult<'src, ()> {
+  ) -> CompileResult<'src, ()> {
     self.advance()?;
 
     if self.accepted(second)? {
@@ -634,7 +634,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex an opening or closing delimiter
-  fn lex_delimiter(&mut self, kind: TokenKind) -> CompilationResult<'src, ()> {
+  fn lex_delimiter(&mut self, kind: TokenKind) -> CompileResult<'src, ()> {
     use Delimiter::*;
 
     match kind {
@@ -663,7 +663,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Pop a delimiter from the open delimiter stack and error if incorrect type
-  fn close_delimiter(&mut self, close: Delimiter) -> CompilationResult<'src, ()> {
+  fn close_delimiter(&mut self, close: Delimiter) -> CompileResult<'src, ()> {
     match self.open_delimiters.pop() {
       Some((open, _)) if open == close => Ok(()),
       Some((open, open_line)) => Err(self.error(MismatchedClosingDelimiter {
@@ -681,12 +681,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex a two-character digraph
-  fn lex_digraph(
-    &mut self,
-    left: char,
-    right: char,
-    token: TokenKind,
-  ) -> CompilationResult<'src, ()> {
+  fn lex_digraph(&mut self, left: char, right: char, token: TokenKind) -> CompileResult<'src, ()> {
     self.presume(left)?;
 
     if self.accepted(right)? {
@@ -708,7 +703,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex a token starting with ':'
-  fn lex_colon(&mut self) -> CompilationResult<'src, ()> {
+  fn lex_colon(&mut self) -> CompileResult<'src, ()> {
     self.presume(':')?;
 
     if self.accepted('=')? {
@@ -722,7 +717,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex a carriage return and line feed
-  fn lex_eol(&mut self) -> CompilationResult<'src, ()> {
+  fn lex_eol(&mut self) -> CompileResult<'src, ()> {
     if self.accepted('\r')? {
       if !self.accepted('\n')? {
         return Err(self.error(UnpairedCarriageReturn));
@@ -743,7 +738,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex name: [a-zA-Z_][a-zA-Z0-9_]*
-  fn lex_identifier(&mut self) -> CompilationResult<'src, ()> {
+  fn lex_identifier(&mut self) -> CompileResult<'src, ()> {
     self.advance()?;
 
     while let Some(c) = self.next {
@@ -760,7 +755,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex comment: #[^\r\n]
-  fn lex_comment(&mut self) -> CompilationResult<'src, ()> {
+  fn lex_comment(&mut self) -> CompileResult<'src, ()> {
     self.presume('#')?;
 
     while !self.at_eol_or_eof() {
@@ -773,7 +768,7 @@ impl<'src> Lexer<'src> {
   }
 
   /// Lex whitespace: [ \t]+
-  fn lex_whitespace(&mut self) -> CompilationResult<'src, ()> {
+  fn lex_whitespace(&mut self) -> CompileResult<'src, ()> {
     while self.next_is_whitespace() {
       self.advance()?;
     }
@@ -788,7 +783,7 @@ impl<'src> Lexer<'src> {
   /// Backtick:      `[^`]*`
   /// Cooked string: "[^"]*" # also processes escape sequences
   /// Raw string:    '[^']*'
-  fn lex_string(&mut self) -> CompilationResult<'src, ()> {
+  fn lex_string(&mut self) -> CompileResult<'src, ()> {
     let kind = if let Some(kind) = StringKind::from_token_start(self.rest()) {
       kind
     } else {
@@ -980,12 +975,12 @@ mod tests {
     line: usize,
     column: usize,
     length: usize,
-    kind: CompilationErrorKind,
+    kind: CompileErrorKind,
   ) {
     match Lexer::lex(src) {
       Ok(_) => panic!("Lexing succeeded but expected"),
       Err(have) => {
-        let want = CompilationError {
+        let want = CompileError {
           token: Token {
             kind: have.token.kind,
             src,
@@ -2285,9 +2280,10 @@ mod tests {
 
   #[test]
   fn presume_error() {
+    let compile_error = Lexer::new("!").presume('-').unwrap_err();
     assert_matches!(
-      Lexer::new("!").presume('-').unwrap_err(),
-      CompilationError {
+      compile_error,
+      CompileError {
         token: Token {
           offset: 0,
           line:   0,
@@ -2297,22 +2293,18 @@ mod tests {
           kind:   Unspecified,
         },
         kind:  Internal {
-          message,
+          ref message,
         },
       } if message == "Lexer presumed character `-`"
     );
 
     assert_eq!(
-      Lexer::new("!").presume('-').unwrap_err().to_string(),
-      unindent(
-        "
-        Internal error, this may indicate a bug in just: Lexer presumed character `-`
-        \
-         consider filing an issue: https://github.com/casey/just/issues/new
-          |
-        1 | !
-          | ^"
-      ),
+      Error::Compile { compile_error }
+        .color_display(Color::never())
+        .to_string(),
+      "error: Internal error, this may indicate a bug in just: \
+      Lexer presumed character `-`\nconsider filing an issue: \
+      https://github.com/casey/just/issues/new\n  |\n1 | !\n  | ^"
     );
   }
 }
