@@ -2,20 +2,16 @@ use crate::common::*;
 
 use std::process::{ExitStatus, Stdio};
 
-/// Return a `RuntimeError::Signal` if the process was terminated by a signal,
-/// otherwise return an `RuntimeError::UnknownFailure`
-fn error_from_signal(
-  recipe: &str,
-  line_number: Option<usize>,
-  exit_status: ExitStatus,
-) -> RuntimeError {
+/// Return a `Error::Signal` if the process was terminated by a signal,
+/// otherwise return an `Error::UnknownFailure`
+fn error_from_signal(recipe: &str, line_number: Option<usize>, exit_status: ExitStatus) -> Error {
   match Platform::signal_from_exit_status(exit_status) {
-    Some(signal) => RuntimeError::Signal {
+    Some(signal) => Error::Signal {
       recipe,
       line_number,
       signal,
     },
-    None => RuntimeError::Unknown {
+    None => Error::Unknown {
       recipe,
       line_number,
     },
@@ -25,14 +21,15 @@ fn error_from_signal(
 /// A recipe, e.g. `foo: bar baz`
 #[derive(PartialEq, Debug, Clone)]
 pub(crate) struct Recipe<'src, D = Dependency<'src>> {
+  pub(crate) body:         Vec<Line<'src>>,
   pub(crate) dependencies: Vec<D>,
   pub(crate) doc:          Option<&'src str>,
-  pub(crate) body:         Vec<Line<'src>>,
   pub(crate) name:         Name<'src>,
   pub(crate) parameters:   Vec<Parameter<'src>>,
   pub(crate) private:      bool,
   pub(crate) quiet:        bool,
   pub(crate) shebang:      bool,
+  pub(crate) priors:       usize,
 }
 
 impl<'src, D> Recipe<'src, D> {
@@ -107,20 +104,18 @@ impl<'src, D> Recipe<'src, D> {
         return Ok(());
       }
 
-      let shebang_line = evaluated_lines
-        .first()
-        .ok_or_else(|| RuntimeError::Internal {
-          message: "evaluated_lines was empty".to_owned(),
-        })?;
+      let shebang_line = evaluated_lines.first().ok_or_else(|| Error::Internal {
+        message: "evaluated_lines was empty".to_owned(),
+      })?;
 
-      let shebang = Shebang::new(shebang_line).ok_or_else(|| RuntimeError::Internal {
+      let shebang = Shebang::new(shebang_line).ok_or_else(|| Error::Internal {
         message: format!("bad shebang line: {}", shebang_line),
       })?;
 
       let tmp = tempfile::Builder::new()
         .prefix("just")
         .tempdir()
-        .map_err(|error| RuntimeError::TmpdirIoError {
+        .map_err(|error| Error::TmpdirIo {
           recipe:   self.name(),
           io_error: error,
         })?;
@@ -129,7 +124,7 @@ impl<'src, D> Recipe<'src, D> {
       path.push(shebang.script_filename(self.name()));
 
       {
-        let mut f = fs::File::create(&path).map_err(|error| RuntimeError::TmpdirIoError {
+        let mut f = fs::File::create(&path).map_err(|error| Error::TmpdirIo {
           recipe:   self.name(),
           io_error: error,
         })?;
@@ -157,14 +152,14 @@ impl<'src, D> Recipe<'src, D> {
         }
 
         f.write_all(text.as_bytes())
-          .map_err(|error| RuntimeError::TmpdirIoError {
+          .map_err(|error| Error::TmpdirIo {
             recipe:   self.name(),
             io_error: error,
           })?;
       }
 
       // make the script executable
-      Platform::set_execute_permission(&path).map_err(|error| RuntimeError::TmpdirIoError {
+      Platform::set_execute_permission(&path).map_err(|error| Error::TmpdirIo {
         recipe:   self.name(),
         io_error: error,
       })?;
@@ -172,7 +167,7 @@ impl<'src, D> Recipe<'src, D> {
       // create a command to run the script
       let mut command =
         Platform::make_shebang_command(&path, &context.search.working_directory, shebang).map_err(
-          |output_error| RuntimeError::Cygpath {
+          |output_error| Error::Cygpath {
             recipe: self.name(),
             output_error,
           },
@@ -189,7 +184,7 @@ impl<'src, D> Recipe<'src, D> {
         Ok(exit_status) =>
           if let Some(code) = exit_status.code() {
             if code != 0 {
-              return Err(RuntimeError::Code {
+              return Err(Error::Code {
                 recipe: self.name(),
                 line_number: None,
                 code,
@@ -199,7 +194,7 @@ impl<'src, D> Recipe<'src, D> {
             return Err(error_from_signal(self.name(), None, exit_status));
           },
         Err(io_error) => {
-          return Err(RuntimeError::Shebang {
+          return Err(Error::Shebang {
             recipe: self.name(),
             command: shebang.interpreter.to_owned(),
             argument: shebang.argument.map(String::from),
@@ -282,7 +277,7 @@ impl<'src, D> Recipe<'src, D> {
           Ok(exit_status) =>
             if let Some(code) = exit_status.code() {
               if code != 0 && !infallable_command {
-                return Err(RuntimeError::Code {
+                return Err(Error::Code {
                   recipe: self.name(),
                   line_number: Some(line_number),
                   code,
@@ -296,7 +291,7 @@ impl<'src, D> Recipe<'src, D> {
               ));
             },
           Err(io_error) => {
-            return Err(RuntimeError::IoError {
+            return Err(Error::Io {
               recipe: self.name(),
               io_error,
             });
@@ -314,8 +309,8 @@ impl<'src, D> Keyed<'src> for Recipe<'src, D> {
   }
 }
 
-impl<'src, D: Display> Display for Recipe<'src, D> {
-  fn fmt(&self, f: &mut Formatter) -> Result<(), fmt::Error> {
+impl<'src, D: Display> ColorDisplay for Recipe<'src, D> {
+  fn fmt(&self, f: &mut Formatter, color: Color) -> Result<(), fmt::Error> {
     if let Some(doc) = self.doc {
       writeln!(f, "# {}", doc)?;
     }
@@ -327,10 +322,15 @@ impl<'src, D: Display> Display for Recipe<'src, D> {
     }
 
     for parameter in &self.parameters {
-      write!(f, " {}", parameter)?;
+      write!(f, " {}", parameter.color_display(color))?;
     }
     write!(f, ":")?;
-    for dependency in &self.dependencies {
+
+    for (i, dependency) in self.dependencies.iter().enumerate() {
+      if i == self.priors {
+        write!(f, " &&")?;
+      }
+
       write!(f, " {}", dependency)?;
     }
 
