@@ -3,16 +3,6 @@ use crate::common::*;
 #[derive(Debug, Snafu)]
 #[snafu(visibility(pub(crate)))]
 pub(crate) enum SearchError {
-  #[snafu(display(
-    "Multiple candidate justfiles found in `{}`: {}",
-    candidates[0].parent().unwrap().display(),
-    List::and_ticked(
-      candidates
-        .iter()
-        .map(|candidate| candidate.file_name().unwrap().to_string_lossy())
-    ),
-  ))]
-  MultipleCandidates { candidates: Vec<PathBuf> },
   #[snafu(display(
     "I/O error reading directory `{}`: {}",
     directory.display(),
@@ -22,14 +12,22 @@ pub(crate) enum SearchError {
     directory: PathBuf,
     io_error:  io::Error,
   },
-  #[snafu(display("No justfile found"))]
-  NotFound,
   #[snafu(display("Justfile path had no parent: {}", path.display()))]
   JustfileHadNoParent { path: PathBuf },
+  #[snafu(display(
+    "Multiple candidate justfiles found in `{}`: {}",
+    candidates.iter().next().unwrap().parent().unwrap().display(),
+    List::and_ticked(
+      candidates
+        .iter()
+        .map(|candidate| candidate.file_name().unwrap().to_string_lossy())
+    ),
+  ))]
+  MultipleCandidates { candidates: BTreeSet<PathBuf> },
+  #[snafu(display("No justfile found"))]
+  NotFound,
 }
 
-impl Error for SearchError {}
-
 #[cfg(test)]
 mod tests {
   use super::*;
@@ -37,15 +35,15 @@ mod tests {
   #[test]
   fn multiple_candidates_formatting() {
     let error = SearchError::MultipleCandidates {
-      candidates: vec![
-        PathBuf::from("/foo/justfile"),
-        PathBuf::from("/foo/JUSTFILE"),
-      ],
+      candidates: [Path::new("/foo/justfile"), Path::new("/foo/JUSTFILE")]
+        .iter()
+        .map(|path| path.to_path_buf())
+        .collect(),
     };
 
     assert_eq!(
       error.to_string(),
-      "Multiple candidate justfiles found in `/foo`: `justfile` and `JUSTFILE`"
+      "Multiple candidate justfiles found in `/foo`: `JUSTFILE` and `justfile`"
     );
   }
 }
