@@ -15,11 +15,13 @@ impl<'src> Token<'src> {
     &self.src[self.offset..self.offset + self.length]
   }
 
-  pub(crate) fn error(&self, kind: CompilationErrorKind<'src>) -> CompilationError<'src> {
-    CompilationError { token: *self, kind }
+  pub(crate) fn error(&self, kind: CompileErrorKind<'src>) -> CompileError<'src> {
+    CompileError { token: *self, kind }
   }
+}
 
-  pub(crate) fn write_context(&self, f: &mut Formatter, color: Color) -> fmt::Result {
+impl<'src> ColorDisplay for Token<'src> {
+  fn fmt(&self, f: &mut Formatter, color: Color) -> fmt::Result {
     let width = if self.length == 0 { 1 } else { self.length };
 
     let line_number = self.line.ordinal();
@@ -73,6 +75,7 @@ impl<'src> Token<'src> {
           )?;
         },
     }
+
     Ok(())
   }
 }
