@@ -2,21 +2,26 @@ pub(crate) use std::{
   collections::BTreeMap,
   env::{self, consts::EXE_SUFFIX},
   error::Error,
+  fmt::Debug,
   fs,
   io::Write,
   iter,
-  path::Path,
+  path::{Path, PathBuf},
   process::{Command, Output, Stdio},
   str,
 };
 
+pub(crate) use cradle::cmd_unit;
 pub(crate) use executable_path::executable_path;
 pub(crate) use just::unindent;
 pub(crate) use libc::{EXIT_FAILURE, EXIT_SUCCESS};
-pub(crate) use temptree::temptree;
+pub(crate) use pretty_assertions::Comparison;
+pub(crate) use regex::Regex;
+pub(crate) use tempfile::TempDir;
+pub(crate) use temptree::{temptree, tree, Tree};
 pub(crate) use which::which;
 pub(crate) use yaml_rust::YamlLoader;
 
 pub(crate) use crate::{
-  assert_stdout::assert_stdout, assert_success::assert_success, tempdir::tempdir,
+  assert_stdout::assert_stdout, assert_success::assert_success, tempdir::tempdir, test::Test,
 };
