@@ -1,11 +1,8 @@
-use executable_path::executable_path;
-use std::{process, str};
-
-use test_utilities::tmptree;
+use crate::common::*;
 
 #[test]
 fn dotenv() {
-  let tmp = tmptree! {
+  let tmp = temptree! {
     ".env": "KEY=ROOT",
     sub: {
       ".env": "KEY=SUB",
@@ -15,7 +12,7 @@ fn dotenv() {
 
   let binary = executable_path("just");
 
-  let output = process::Command::new(binary)
+  let output = Command::new(binary)
     .current_dir(tmp.path())
     .arg("sub/default")
     .output()
@@ -63,27 +60,44 @@ test! {
   stderr:   "echo $DOTENV_KEY\n",
 }
 
-// Un-comment this on 2021-07-01.
-//
-// test! {
-//   name:     warning,
-//   justfile: r#"
-//     foo:
-//       echo $DOTENV_KEY
-//   "#,
-//   stdout:   "dotenv-value\n",
-//   stderr:   "
-//     warning: A `.env` file was found and loaded, but this behavior will
-// change in the future.     To silence this warning and continue loading `.env`
-// files, add:
+#[test]
+fn warning() {
+  Test::new()
+    .justfile(
+      "
+      foo:
+        echo $DOTENV_KEY
+    ",
+    )
+    .stdout("dotenv-value\n")
+    .stderr(
+      "
+warning: A `.env` file was found and loaded, but this behavior will change in the future.
 
-//         set dotenv-load := true
+To \
+       silence this warning and continue loading `.env` files, add:
 
-//     To silence this warning and stop loading `.env` files, add:
+    set dotenv-load := true
 
-//         set dotenv-load := false
+To silence \
+       this warning and stop loading `.env` files, add:
 
-//     See https://github.com/casey/just/issues/469 for more details.
-//     echo $DOTENV_KEY
-//   ",
-// }
+    set dotenv-load := false
+
+This warning may \
+       also be silenced by setting the `JUST_SUPPRESS_DOTENV_LOAD_WARNING`
+environment variable to `1`. \
+       This can be used to silence the warning globally by
+adding the following line to your shell rc \
+       file:
+
+  export JUST_SUPPRESS_DOTENV_LOAD_WARNING=1
+
+See https://github.com/casey/just/issues/469 \
+       for more details.
+echo $DOTENV_KEY
+   ",
+    )
+    .suppress_dotenv_load_warning(false)
+    .run();
+}
